kedro.framework.cli.hooks.specs.CLICommandSpecs — Kedro 0.17.6 documentation

# kedro.framework.cli.hooks.specs.CLICommandSpecs

class `kedro.framework.cli.hooks.specs.` `CLICommandSpecs`

  Namespace that defines all specifications for Kedro CLI’s lifecycle hooks.

  Methods

  `before_command_run`(project_metadata, …) | Hooks to be invoked before a CLI command runs.

  `before_command_run`(project_metadata, command_args)

    Hooks to be invoked before a CLI command runs. It receives the `project_metadata` as well as all command line arguments that were used, including the command and subcommand themselves.

    Parameters

      - project_metadata (`ProjectMetadata`) – The Kedro project’s metadata.

      - command_args (`List`[`str`]) – The command line arguments that were used.